@@ -10,8 +10,24 @@ use lib ("$Bin/../lib", "$Bin/../../../lib");
 
 use Raisin::API;
 
-api_format 'yaml';
-plugin 'Swagger';
+plugin 'Swagger', enable => 'CORS';
+plugin 'Logger', outputs => [['Screen', min_level => 'debug']];
+
+swagger_setup(
+    title => 'Users & hosts API',
+    description => 'An example of API documentation.',
+
+    contact => {
+        name => 'Artur Khabibullin',
+        url => 'http://github.com/khrt',
+        email => 'rtkh@cpan.org',
+    },
+
+    license => {
+        name => 'Perl license',
+        url => 'http://dev.perl.org/licenses/',
+    },
+);
 
 #before sub {
 #    my $self = shift;
