@@ -11,7 +11,7 @@ use Raisin::Response;
 use Raisin::Routes;
 use Raisin::Util;
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 
 sub new {
     my ($class, %args) = @_;
@@ -74,7 +74,7 @@ sub add_hook {
 # Application
 sub run {
     my $self = shift;
-    my $app = sub { $self->psgi(@_) };
+    my $psgi = sub { $self->psgi(@_) };
 
     # Add middleware
     for my $class (keys %{ $self->{middleware} }) {
@@ -83,13 +83,13 @@ sub run {
 
         my $mw = Plack::Util::load_class($class, 'Plack::Middleware');
         my $args = $self->{middleware}{$class};
-        $app = $mw->wrap($app, @$args);
+        $psgi = $mw->wrap($psgi, @$args);
     }
 
     # load fallback logger (Raisin::Logger)
     $self->load_plugin('Logger', fallback => 1);
 
-    return $app;
+    return $psgi;
 }
 
 sub psgi {
@@ -131,15 +131,15 @@ sub psgi {
 
         $self->hook('before_validation')->($self);
 
-        # Validation and coercion of a declared params
-        if (not $req->prepare_params($route->params, $route->named)) {
-            $res->render_error(400, 'Invalid params!');
+        # Validation and coercion of declared params
+        if (!$req->prepare_params($route->params, $route->named)) {
+            $res->render_error(400, 'Invalid params.');
             return $res->finalize;
         }
 
         $self->hook('after_validation')->($self);
 
-        # Eval user endpoint
+        # Evaluate a user's endpoint
         my $data = $code->($req->declared_params);
         if (defined $data) {
             # TODO: delayed responses are untested
@@ -375,7 +375,9 @@ Raisin is a REST API micro framework for Perl.
 It's designed to run on Plack, providing a simple DSL to easily develop RESTful APIs.
 It was inspired by L<Grape|https://github.com/intridea/grape>.
 
-=for HTML <a href="https://travis-ci.org/khrt/Raisin"><img src="https://travis-ci.org/khrt/Raisin.svg?branch=master"></a>
+=for HTML
+<a href="https://travis-ci.org/khrt/Raisin"><img src="https://travis-ci.org/khrt/Raisin.svg?branch=master"></a>
+<a href="http://badge.fury.io/pl/Raisin"><img src="https://badge.fury.io/pl/Raisin.svg" alt="CPAN version" height="18"></a>
 
 =head1 FUNCTIONS
 
@@ -597,7 +599,7 @@ For details see examples in I<examples/music-app> and L<Raisin::Entity>.
 
 =head1 PARAMETERS
 
-A request parameters are available through the C<params> C<HASH>. This includes
+Request parameters are available through the C<params> C<HASH>. This includes
 GET, POST and PUT parameters, along with any named parameters you specify in
 your route strings.
 
@@ -606,14 +608,11 @@ on C<POST> and C<PUT> for form input, C<JSON> and C<YAML> content-types.
 
 The request:
 
-    curl -d '{"id": "14"}' 'http://localhost:5000/data' -H Content-Type:application/json -v
+    curl localhost:5000/data -H Content-Type:application/json -d '{"id": "14"}'
 
 The Raisin endpoint:
 
-    post data => sub {
-        my $params = shift;
-        $params{id};
-    }
+    post data => sub { param('id') };
 
 Multipart C<POST>s and C<PUT>s are supported as well.
 
@@ -633,6 +632,77 @@ route string parameters will have precedence.
 
 Query string and body parameters will be merged (see L<Plack::Request/parameters>)
 
+=head2 Declared parameters
+
+Raisin allows you to access only the parameters that have been declared by your
+L<Raisin/params> block.
+
+By default you can get all declared parameter as a first argument passed to your
+route subroutine.
+
+Application:
+
+    api_format 'json';
+
+    post data => sub {
+        my $params = shift;
+        { data => $params };
+    };
+
+Request:
+
+    curl -X POST -H "Content-Type: application/json" localhost:5000/signup -d '{"id": 42}'
+
+Response:
+
+    { "data": nil }
+
+Once we add parameters requirements, Raisin will start returning only
+the declared params.
+
+Application:
+
+    api_format 'json';
+
+    params
+        required => { name => 'id', type => Int };
+        optional => { name => 'email', type => Str };
+    post data => sub {
+        my $params = shift;
+        { data => $params };
+    };
+
+Request:
+
+    curl -X POST -H "Content-Type: application/json" localhost:5000/signup -d '{"id": 42, "key": "value"}'
+
+Response:
+
+    { "data": { "id": 42 } }
+
+By default declared parameters doesn't contain parameters that has C<undef> value.
+If you want to return all parameters you can use the C<include_missing> function.
+
+Application:
+
+    api_format 'json';
+
+    params
+        required => { name => 'id', type => Int },
+        optional => { name => 'email', type => Str };
+    post data => sub {
+        my $params = shift;
+        { data => include_missing($params) };
+    };
+
+Request:
+
+    curl -X POST -H "Content-Type: application/json" localhost:5000/signup -d '{"id": 42, "key": "value"}'
+
+Response:
+
+    { "data": { "id": 42, "email": null } }
+
 =head2 Validation and coercion
 
 You can define validations and coercion options for your parameters using a
@@ -935,12 +1005,18 @@ Shows an example of complex application.
 
 =over
 
-=item * Endpoint's hooks: C<after>, C<before>;
+=item * OPTIONS/Allow support;
+
+=item * C<param> doesn't work as expected;
+
+=item * Support for hypermedia (L<HAL|http://stateless.co/hal_specification.html>, L<Link headers|http://www.w3.org/wiki/LinkHeader>);
+
+=item * Versioning support;
+
+=item * Nested params declaration;
 
 =item * Mount API's in any place of C<resource> block;
 
-=item * C<declared> keyword which should be applicable to C<param> and supports for C<missing> keyword;
-
 =back
 
 =head1 GITHUB
