@@ -15,7 +15,7 @@ my @APP_EXEC_METHODS = qw(new run);
 my @APP_METHODS = qw(req res param session present error);
 my @HOOKS_METHODS = qw(before before_validation after_validation after);
 my @HTTP_METHODS = qw(del get head options patch post put);
-my @ROUTES_METHODS = qw(resource namespace route_param params);
+my @ROUTES_METHODS = qw(resource namespace route_param params include_missing);
 
 my @SWAGGER_MERTHODS = qw(desc summary tags);
 
@@ -126,7 +126,13 @@ sub _add_route {
     my $code = pop @params;
 
     my ($method, $path) = @params;
-    $path = resource() . ($path ? "/$path" : '');
+    my $r = resource();
+    if ($r eq '/' && $path) {
+        $path = $r . $path;
+    }
+    else {
+        $path = $r . ($path ? "/$path" : '');
+    }
 
     $app->add_route(
         code    => $code,
@@ -170,6 +176,12 @@ sub present {
     return;
 }
 
+sub include_missing {
+    my $p = shift;
+    my %pp = map { $_->name, $p->{ $_->name } } @{ $app->req->{'raisin.declared'} };
+    \%pp;
+}
+
 #
 # System
 #
@@ -178,7 +190,9 @@ sub plugin { $app->load_plugin(@_) }
 sub api_default_format { $app->api_default_format(@_) }
 sub api_format { $app->api_format(@_) }
 
-# TODO: add namespace with version name/number
+# TODO:
+# prepend a resource with a version number
+# http://example.com/api/1
 sub api_version { $app->api_version(@_) }
 
 #
